==> hoteldruid_2.0.3.orig.tar.gz: hoteldruid/includes/lang/en/clienti.php <==
<?php

switch ($messaggio) {

case "Le date sono sbagliate":  		$messaggio = "The dates are wrong"; break;
case "Si deve inserire il tipo di tariffa":  	$messaggio = "You must insert the rate type"; break;
case "tariffa":  				$messaggio = "rate"; break;
case "Non è stato ancora inserito il prezzo della":	$messaggio = "You must still insert the price of"; break;
case "per la settimana dal":  			$messaggio = "for the week from"; break;
case "per il giorno dal":  			$messaggio = "for the day from"; break;
case "al":  					$messaggio = "to"; break;
case "La settimana dal":  			$messaggio = "The week from"; break;
case "Il giorno dal":  				$messaggio = "The day from"; break;
case "è piena":  				$messaggio = "is full"; break;
case "è pieno":  				$messaggio = "is full"; break;
case "Il numero di settimane del costo aggiuntivo settimanale nº":	$messaggio = "The number of weeks of the weekly extra cost n°"; break;
case "Il numero di giorni del costo aggiuntivo giornaliero nº":	$messaggio = "The number of days of the daily extra cost n°"; break;
case "supera il numero totale di settimane della prenotazione":	$messaggio = "is bigger than the number of weeks of the reservation"; break;
case "supera il numero totale di giorni della prenotazione":	$messaggio = "is bigger than the number of days of the reservation"; break;
case "persone":  				$messaggio = "people"; break;
case "Si dovrà occupare almeno un periodo della regola di assegnazione 1":	$messaggio = "At least one period of the assignment rule 1 will have to be occupied"; break;
case "Si devono fare i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "Movements that must be done in the periods of the <div style=\"display: inline; color: blue;\">assignment rule 1</div>"; break;
case "Sono stati fatti i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "Movements that have been done in the periods of the <div style=\"display: inline; color: blue;\">assignment rule 1</div>"; break;
case "La prenotazione dal":  			$messaggio = "The reservation from"; break;
case "a nome di":  				$messaggio = "for Mr/Ms"; break;
case "Non si può procedere perchè la tabella prenotazioni è cambiata nel frattempo":	$messaggio = "Can't continue because the reservations table has changed meanwhile"; break;
case "Continua lo stesso":  			$messaggio = "Continue anyway"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "Non esistono clienti chiamati":  		$messaggio = "There are no clients called"; break;
case "nel database":  				$messaggio = "in the database"; break;
case "Inserisci i dati di un nuovo cliente":  	$messaggio = "Insert a new client's data"; break;
case "Esistono i seguenti clienti con un cognome uguale o simile":	$messaggio = "There are already these clients with the same or similar surname"; break;
case "Esistono i seguenti clienti con un cognome e nome uguale o simile":	$messaggio = "There are already these clients with the same or similar surname and name"; break;
case "nato il":	  				$messaggio = "born the"; break;
case "nata il":	  				$messaggio = "born the"; break;
case "CAP":  					$messaggio = "postal code"; break;
case "Telefono":  				$messaggio = "Phone n°"; break;
case "2º telefono":  				$messaggio = "2nd phone n°"; break;
case "3º telefono":  				$messaggio = "3rd phone n°"; break;
case "Utilizza il cliente":  			$messaggio = "Use client"; break;
case "per la prenotazione":  			$messaggio = "for the reservation"; break;
case "Modifica i dati del cliente":  		$messaggio = "Modify the data of client"; break;
case "Inserisci un nuovo cliente":  		$messaggio = "Insert a new client"; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "The client's surname is needed"; break;
case "I dati del cliente":  			$messaggio = "The data of client"; break;
case "sono stati inseriti":  			$messaggio = "have been inserted"; break;
case "Inserisci o modifica i dati di un cliente":	$messaggio = "Insert or modify a client's data"; break;
case "Cognome":  				$messaggio = "Surname"; break;
case "nome":  					$messaggio = "name"; break;
case "sesso":  					$messaggio = "gender"; break;
case "Data di nascita":  			$messaggio = "Birthdate"; break;
case "anno con 4 cifre":  			$messaggio = "year with 4 digits"; break;
case "Nazione":  				$messaggio = "Nation"; break;
case "città":  					$messaggio = "city"; break;
case "Via":  					$messaggio = "Street"; break;
case "Piazza":  				$messaggio = "Square"; break;
case "Viale":  					$messaggio = "Avenue"; break;
case "Piazzale":  				$messaggio = "Boulevard"; break;
case "Vicolo":  				$messaggio = "Road"; break;
case "Numero di telefono":  			$messaggio = "Telephone number"; break;
case "Secondo telefono":  			$messaggio = "Second telephone"; break;
case "Terzo telefono":  			$messaggio = "Third telephone"; break;
case "Numero di fax":  				$messaggio = "Fax number"; break;
case "Seconda persona di riferimento":  	$messaggio = "Second reference person"; break;
case "Inserisci i dati":  			$messaggio = "Insert data"; break;
case "Torna al menù principale":  		$messaggio = "Back to main menu"; break;
case "Italia":  				$messaggio = ""; break;
case "non verrano modificati i dati specifici delle 2 persone di riferimento":	$messaggio = "data specific to the 2 reference people will not be changed"; break;
case "sono stati modificati":  			$messaggio = "have been modified"; break;
case "e":  					$messaggio = "and"; break;
case "Il numero di prenotazioni è sbagliato":	$messaggio = "The number of reservations is wrong"; break;
case "Aggiungi":  				$messaggio = "Add"; break;
case "Nº di tipologie da aggiungere":  		$messaggio = "Number of types to add"; break;
case "Non si è trovato nessun cliente chiamato":	$messaggio = "There are no clients called"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "There are no periods in assignment rule 1 in which is allowed to insert reservations for user"; break;
case "Il numero di persone è sbagliato":  	$messaggio = "The number of people is wrong"; break;
case "I dati di un costo aggiuntivo sono errati":	$messaggio = "Data from and extra cost is wrong"; break;
case "Non si può inserire più di un costo aggiuntivo con percentuale sul prezzo totale per prenotazione":	$messaggio = "You can't insert more than one extra cost with percentage on total price per reservation"; break;
case "Non si puo inserire il costo aggiuntivo":	$messaggio = "The extra cost"; break;
case "in questo periodo":  			$messaggio = "can't be inserted in this period"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Choose the weeks to be applied for the extra cost"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Choose the days to be applied for the extra cost"; break;
case "Continua":  				$messaggio = "Continue"; break;
case "Non si possono inserire altri costi":  	$messaggio = "You can't insert more costs"; break;
case "in questo periodo, già":  		$messaggio = "in this period, already"; break;
case "presenti":  				$messaggio = "present"; break;
case "Si deve inserire il numero delle persone per il costo aggiuntivo":	$messaggio = "The number of people must be inserted for the extra cost"; break;
case "Il costo aggiuntivo":  			$messaggio = "The extra cost"; break;
case "è incompatibile con la tariffa selezionata":	$messaggio = "is incompatible with selected rate"; break;
case "non può essere applicato":  		$messaggio = "can't be applied"; break;
case "regione":  				$messaggio = "region"; break;
case "Documento":  				$messaggio = "Document"; break;
case "scadenza":  				$messaggio = "expiration"; break;
case "Torna all'inserimento clienti":  		$messaggio = "Back to clients insertion"; break;
case "Annulla":  				$messaggio = "Cancel"; break;
case "Ospite della prenotazione":  		$messaggio = "Guest of reservation"; break;
case "tipologia":  				$messaggio = "type"; break;
case "Ospiti della prenotazione":  		$messaggio = "Guests of reservation"; break;
case "Altri ospiti":  				$messaggio = "Other guests"; break;
case "nato":  					$messaggio = "born"; break;
case "nata":  					$messaggio = "born"; break;
case "il":  					$messaggio = "the"; break;
case " a":  					$messaggio = " in"; break;
case "scade":  					$messaggio = "expires"; break;
case "cittadinanza":  				$messaggio = "nationality"; break;
case "città di nascita":  			$messaggio = "city of birth"; break;
case "reg./prov. di nascita":  			$messaggio = "region of birth"; break;
case "nazione di nascita":  			$messaggio = "nation of birth"; break;
case "Residenza":  				$messaggio = "Residency"; break;
case "reg./prov.":  				$messaggio = "region"; break;
case "nazione":  				$messaggio = "nation"; break;
case "rilasciato da":  				$messaggio = "released by"; break;
case "nazione di rilascio":  			$messaggio = "releasing nation"; break;
case "parentela":  				$messaggio = "relatedness"; break;
case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "with selected extra costs"; break;
case "I beni richiesti dal costo":  		$messaggio = "Goods needed by cost"; break;
case "non sono disponibili nell'inventario":  	$messaggio = "are not available in the inventory"; break;
case "Si deve inserire il numero delle persone per questa tariffa":	$messaggio = "The number of people must be inserted for this rate"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "lo sconto è sbagliato":  			$messaggio = "the discount is wrong"; break;
case "la caparra è sbagliata":  		$messaggio = "the deposit is wrong"; break;
case "soprannome":  				$messaggio = "nickname"; break;
case "le commissioni sono sbagliate":  		$messaggio = "commissions are wrong"; break;
case "lingua":  				$messaggio = "language"; break;
case "ln.":  					$messaggio = "ln."; break;
case "non può essere moltiplicato per più di":	$messaggio = "can not be multiplied by more than"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid_2.1.0.orig.tar.gz: hoteldruid/includes/lang/en/clienti.php <==
<?php

switch ($messaggio) {

case "Le date sono sbagliate":  		$messaggio = "The dates are wrong"; break;
case "Si deve inserire il tipo di tariffa":  	$messaggio = "You must insert the rate type"; break;
case "tariffa":  				$messaggio = "rate"; break;
case "Non è stato ancora inserito il prezzo della":	$messaggio = "You must still insert the price of"; break;
case "per la settimana dal":  			$messaggio = "for the week from"; break;
case "per il giorno dal":  			$messaggio = "for the day from"; break;
case "al":  					$messaggio = "to"; break;
case "La settimana dal":  			$messaggio = "The week from"; break;
case "Il giorno dal":  				$messaggio = "The day from"; break;
case "è piena":  				$messaggio = "is full"; break;
case "è pieno":  				$messaggio = "is full"; break;
case "Il numero di settimane del costo aggiuntivo settimanale nº":	$messaggio = "The number of weeks of the weekly extra cost n°"; break;
case "Il numero di giorni del costo aggiuntivo giornaliero nº":	$messaggio = "The number of days of the daily extra cost n°"; break;
case "supera il numero totale di settimane della prenotazione":	$messaggio = "is bigger than the number of weeks of the reservation"; break;
case "supera il numero totale di giorni della prenotazione":	$messaggio = "is bigger than the number of days of the reservation"; break;
case "persone":  				$messaggio = "people"; break;
case "Si dovrà occupare almeno un periodo della regola di assegnazione 1":	$messaggio = "At least one period of the assignment rule 1 will have to be occupied"; break;
case "Si devono fare i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "Movements that must be done in the periods of the <div style=\"display: inline; color: blue;\">assignment rule 1</div>"; break;
case "Sono stati fatti i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "Movements that have been done in the periods of the <div style=\"display: inline; color: blue;\">assignment rule 1</div>"; break;
case "La prenotazione dal":  			$messaggio = "The reservation from"; break;
case "a nome di":  				$messaggio = "for Mr/Ms"; break;
case "Non si può procedere perchè la tabella prenotazioni è cambiata nel frattempo":	$messaggio = "Can't continue because the reservations table has changed meanwhile"; break;
case "Continua lo stesso":  			$messaggio = "Continue anyway"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "Non esistono clienti chiamati":  		$messaggio = "There are no clients called"; break;
case "nel database":  				$messaggio = "in the database"; break;
case "Inserisci i dati di un nuovo cliente":  	$messaggio = "Insert a new client's data"; break;
case "Esistono i seguenti clienti con un cognome uguale o simile":	$messaggio = "There are already these clients with the same or similar surname"; break;
case "Esistono i seguenti clienti con un cognome e nome uguale o simile":	$messaggio = "There are already these clients with the same or similar surname and name"; break;
case "nato il":	  				$messaggio = "born the"; break;
case "nata il":	  				$messaggio = "born the"; break;
case "CAP":  					$messaggio = "postal code"; break;
case "Telefono":  				$messaggio = "Phone n°"; break;
case "2º telefono":  				$messaggio = "2nd phone n°"; break;
case "3º telefono":  				$messaggio = "3rd phone n°"; break;
case "Utilizza il cliente":  			$messaggio = "Use client"; break;
case "per la prenotazione":  			$messaggio = "for the reservation"; break;
case "Modifica i dati del cliente":  		$messaggio = "Modify the data of client"; break;
case "Inserisci un nuovo cliente":  		$messaggio = "Insert a new client"; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "The client's surname is needed"; break;
case "I dati del cliente":  			$messaggio = "The data of client"; break;
case "sono stati inseriti":  			$messaggio = "have been inserted"; break;
case "Inserisci o modifica i dati di un cliente":	$messaggio = "Insert or modify a client's data"; break;
case "Cognome":  				$messaggio = "Surname"; break;
case "nome":  					$messaggio = "name"; break;
case "sesso":  					$messaggio = "gender"; break;
case "Data di nascita":  			$messaggio = "Birthdate"; break;
case "anno con 4 cifre":  			$messaggio = "year with 4 digits"; break;
case "Nazione":  				$messaggio = "Nation"; break;
case "città":  					$messaggio = "city"; break;
case "Via":  					$messaggio = "Street"; break;
case "Piazza":  				$messaggio = "Square"; break;
case "Viale":  					$messaggio = "Avenue"; break;
case "Piazzale":  				$messaggio = "Boulevard"; break;
case "Vicolo":  				$messaggio = "Road"; break;
case "Numero di telefono":  			$messaggio = "Telephone number"; break;
case "Secondo telefono":  			$messaggio = "Second telephone"; break;
case "Terzo telefono":  			$messaggio = "Third telephone"; break;
case "Numero di fax":  				$messaggio = "Fax number"; break;
case "Seconda persona di riferimento":  	$messaggio = "Second reference person"; break;
case "Inserisci i dati":  			$messaggio = "Insert data"; break;
case "Torna al menù principale":  		$messaggio = "Back to main menu"; break;
case "Italia":  				$messaggio = ""; break;
case "non verrano modificati i dati specifici delle 2 persone di riferimento":	$messaggio = "data specific to the 2 reference people will not be changed"; break;
case "sono stati modificati":  			$messaggio = "have been modified"; break;
case "e":  					$messaggio = "and"; break;
case "Il numero di prenotazioni è sbagliato":	$messaggio = "The number of reservations is wrong"; break;
case "Aggiungi":  				$messaggio = "Add"; break;
case "Nº di tipologie da aggiungere":  		$messaggio = "Number of types to add"; break;
case "Non si è trovato nessun cliente chiamato":	$messaggio = "There are no clients called"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "There are no periods in assignment rule 1 in which is allowed to insert reservations for user"; break;
case "Il numero di persone è sbagliato":  	$messaggio = "The number of people is wrong"; break;
case "I dati di un costo aggiuntivo sono errati":	$messaggio = "Data from and extra cost is wrong"; break;
case "Non si può inserire più di un costo aggiuntivo con percentuale sul prezzo totale per prenotazione":	$messaggio = "You can't insert more than one extra cost with percentage on total price per reservation"; break;
case "Non si puo inserire il costo aggiuntivo":	$messaggio = "The extra cost"; break;
case "in questo periodo":  			$messaggio = "can't be inserted in this period"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Choose the weeks to be applied for the extra cost"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Choose the days to be applied for the extra cost"; break;
case "Continua":  				$messaggio = "Continue"; break;
case "Non si possono inserire altri costi":  	$messaggio = "You can't insert more costs"; break;
case "in questo periodo, già":  		$messaggio = "in this period, already"; break;
case "presenti":  				$messaggio = "present"; break;
case "Si deve inserire il numero delle persone per il costo aggiuntivo":	$messaggio = "The number of people must be inserted for the extra cost"; break;
case "Il costo aggiuntivo":  			$messaggio = "The extra cost"; break;
case "è incompatibile con la tariffa selezionata":	$messaggio = "is incompatible with selected rate"; break;
case "non può essere applicato":  		$messaggio = "can't be applied"; break;
case "regione":  				$messaggio = "region"; break;
case "Documento":  				$messaggio = "Document"; break;
case "scadenza":  				$messaggio = "expiration"; break;
case "Torna all'inserimento clienti":  		$messaggio = "Back to clients insertion"; break;
case "Annulla":  				$messaggio = "Cancel"; break;
case "Ospite della prenotazione":  		$messaggio = "Guest of reservation"; break;
case "tipologia":  				$messaggio = "type"; break;
case "Ospiti della prenotazione":  		$messaggio = "Guests of reservation"; break;
case "Altri ospiti":  				$messaggio = "Other guests"; break;
case "nato":  					$messaggio = "born"; break;
case "nata":  					$messaggio = "born"; break;
case "il":  					$messaggio = "the"; break;
case " a":  					$messaggio = " in"; break;
case "scade":  					$messaggio = "expires"; break;
case "cittadinanza":  				$messaggio = "nationality"; break;
case "città di nascita":  			$messaggio = "city of birth"; break;
case "reg./prov. di nascita":  			$messaggio = "region of birth"; break;
case "nazione di nascita":  			$messaggio = "nation of birth"; break;
case "Residenza":  				$messaggio = "Residency"; break;
case "reg./prov.":  				$messaggio = "region"; break;
case "nazione":  				$messaggio = "nation"; break;
case "rilasciato da":  				$messaggio = "released by"; break;
case "nazione di rilascio":  			$messaggio = "releasing nation"; break;
case "parentela":  				$messaggio = "relatedness"; break;
case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "with selected extra costs"; break;
case "I beni richiesti dal costo":  		$messaggio = "Goods needed by cost"; break;
case "non sono disponibili nell'inventario":  	$messaggio = "are not available in the inventory"; break;
case "Si deve inserire il numero delle persone per questa tariffa":	$messaggio = "The number of people must be inserted for this rate"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "lo sconto è sbagliato":  			$messaggio = "the discount is wrong"; break;
case "la caparra è sbagliata":  		$messaggio = "the deposit is wrong"; break;
case "soprannome":  				$messaggio = "nickname"; break;
case "le commissioni sono sbagliate":  		$messaggio = "commissions are wrong"; break;
case "lingua":  				$messaggio = "language"; break;
case "ln.":  					$messaggio = "ln."; break;
case "non può essere moltiplicato per più di":	$messaggio = "can not be multiplied by more than"; break;
case "La tariffa richiesta è chiusa in questo periodo":	$messaggio = "The requested rate is closed in this period"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
